==> SJava_0.72.0.tar.gz: SJava/man/JavaConfiguration-class.Rd <==
\name{JavaConfiguration-class}
\Rdversion{1.1}
\docType{class}
\alias{JavaConfiguration-class}
\alias{JavaConfiguration}
\alias{collapse,JavaConfiguration-method}
\alias{merge,JavaConfiguration,JavaConfiguration-method}

\title{Class "JavaConfiguration"}
\description{Establish configuration parameters for SJava sessions}
\section{Objects from the Class}{
  Use the constructor \code{JavaConfiguration} to create objects from
  the class.
  
  \code{JavaConfiguration(classPath= defaultJavaPath(), libraryPath =
	defaultJavaPath("LD_LIBRARY_PATH"), properties=character(0),
	options=character(0), args=character(0))}

}
\section{Slots}{
	 \describe{
    \item{\code{classPath}:}{\code{character} vector of class
	  paths, one class path per element.}
    \item{\code{libraryPath}:}{\code{character} vector of library paths,
	  one path per element.}

    \item{\code{properties}:}{A \code{character} vector of Java VM
      properties.}
	
    \item{\code{options}:}{A \code{character} vector of Java VM options.}

    \item{\code{args}:}{A \code{character} vector of Java VM arguments.}
  }
}
\section{Methods}{

  Manipulation.
  \describe{

    \item{collapse}{\code{signature(x = "JavaConfiguration")}:
	  re-structure \code{x} into the equivalent command-line
	  representation.}

    \item{merge}{\code{signature(x = "JavaConfiguration", y =
		"JavaConfiguration")}: combine the contents of two
		\code{JavaConfiguration} objects, e.g., collating unique class
		paths.}

	 }
}

\examples{
showClass("JavaConfiguration")
JavaConfiguration()
collapse(JavaConfiguration())
}
\keyword{classes}

==> SJava_0.94.0.tar.gz: SJava/man/JavaConfiguration-class.Rd <==
\name{JavaConfiguration-class}
\Rdversion{1.1}
\docType{class}
\alias{JavaConfiguration-class}
\alias{JavaConfiguration}
\alias{collapse}
\alias{collapse,JavaConfiguration-method}
\alias{merge,JavaConfiguration,JavaConfiguration-method}

\title{Class "JavaConfiguration"}
\description{Establish configuration parameters for SJava sessions}
\section{Objects from the Class}{
  Use the constructor \code{JavaConfiguration} to create objects from
  the class.
  
  \code{JavaConfiguration(classPath= defaultJavaPath(), libraryPath =
	defaultJavaPath("LD_LIBRARY_PATH"), properties=character(0),
	options=character(0), args=character(0))}

}
\section{Slots}{
  \describe{

    \item{\code{classPath}:}{\code{character} vector of class paths, one
	  class path per element.}
    
    \item{\code{libraryPath}:}{\code{character} vector of library paths,
	  one path per element.}

    \item{\code{properties}:}{A \code{character} vector of Java VM
      properties.}
	
    \item{\code{options}:}{A \code{character} vector of Java VM
      options.}

    \item{\code{args}:}{A \code{character} vector of Java VM arguments.}

  }
}
\section{Methods}{

  Manipulation.
  \describe{

    \item{collapse}{\code{signature(x = "JavaConfiguration")}:
	  re-structure \code{x} into the equivalent command-line
	  representation.}

    \item{merge}{\code{signature(x = "JavaConfiguration", y =
		"JavaConfiguration")}: combine the contents of two
		\code{JavaConfiguration} objects, e.g., collating unique class
		paths.}

	}

}

\examples{
showClass("JavaConfiguration")
JavaConfiguration()
collapse(JavaConfiguration())
}
\keyword{classes}
